@@ -125,25 +125,27 @@ class AnnotationWidget(QtWidgets.QWidget):
         self.preview_data = np.stack([self.composites[red_channel].data.copy(),
                                      self.composites[green_channel].data.copy(),
                                      self.composites[blue_channel].data.copy()], axis=2)
-        # self.preview_data[:, :, 0] = np.power(self.preview_data[:, :, 0], red_scale)
-        # self.preview_data[:, :, 1] = np.power(self.preview_data[:, :, 1], green_scale)
-        # self.preview_data[:, :, 2] = np.power(self.preview_data[:, :, 2], blue_scale)
-        #
-        # red_lower = np.nanpercentile(self.preview_data[:, :, 0], red_min)
-        # green_lower = np.nanpercentile(self.preview_data[:, :, 0], green_min)
-        # blue_lower = np.nanpercentile(self.preview_data[:, :, 0], blue_min)
-        # red_upper = np.nanpercentile(self.preview_data[:, :, 0], red_max)
-        # green_upper = np.nanpercentile(self.preview_data[:, :, 0], green_max)
-        # blue_upper = np.nanpercentile(self.preview_data[:, :, 0], blue_max)
-        # self.preview_data[np.where(self.preview_data[:, :, 0]) < red_lower] = red_lower
-        # self.preview_data[np.where(self.preview_data[:, :, 0]) > red_upper] = red_upper
-        # self.preview_data[np.where(self.preview_data[:, :, 1]) < green_lower] = green_lower
-        # self.preview_data[np.where(self.preview_data[:, :, 1]) > green_upper] = green_upper
-        # self.preview_data[np.where(self.preview_data[:, :, 2]) < blue_lower] = blue_lower
-        # self.preview_data[np.where(self.preview_data[:, :, 2]) > blue_upper] = blue_upper
-        #
-        # for index in [0, 1, 2]:
-        #     self.preview_data[:, :, index] /= np.nanmax(self.preview_data[:, :, index])
+        self.preview_data[:, :, 0] = np.power(self.preview_data[:, :, 0], red_scale)
+        self.preview_data[:, :, 1] = np.power(self.preview_data[:, :, 1], green_scale)
+        self.preview_data[:, :, 2] = np.power(self.preview_data[:, :, 2], blue_scale)
+
+        red_lower = np.nanpercentile(self.preview_data[:, :, 0], red_min)
+        green_lower = np.nanpercentile(self.preview_data[:, :, 1], green_min)
+        blue_lower = np.nanpercentile(self.preview_data[:, :, 2], blue_min)
+
+        red_upper = np.nanpercentile(self.preview_data[:, :, 0], red_max)
+        green_upper = np.nanpercentile(self.preview_data[:, :, 1], green_max)
+        blue_upper = np.nanpercentile(self.preview_data[:, :, ], blue_max)
+
+        self.preview_data[self.preview_data[:, :, 0] < red_lower] = red_lower
+        self.preview_data[self.preview_data[:, :, 0] > red_upper] = red_upper
+        self.preview_data[self.preview_data[:, :, 1] < green_lower] = green_lower
+        self.preview_data[self.preview_data[:, :, 1] > green_upper] = green_upper
+        self.preview_data[self.preview_data[:, :, 2] < blue_lower] = blue_lower
+        self.preview_data[self.preview_data[:, :, 2] > blue_upper] = blue_upper
+        
+        for index in [0, 1, 2]:
+            self.preview_data[:, :, index] /= np.nanmax(self.preview_data[:, :, index])
 
         self.preview_axesimage.set_data(self.preview_data)
         self.fig.canvas.draw_idle()
@@ -184,16 +186,19 @@ class ControlWidget(QtWidgets.QWidget):
         self.one_color_min_editor = QLineEdit()
         self.one_color_min_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
         self.one_color_min_editor.setText("0.0")
-        self.one_color_min_editor.textEdited.connect(self.onSingleColorChange)
+        self.one_color_min_editor.editingFinished.connect(self.onSingleColorChange)
 
         self.one_color_max_editor = QLineEdit()
         self.one_color_max_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
-        self.one_color_max_editor.setText("100.0")
-        self.one_color_max_editor.textEdited.connect(self.onSingleColorChange)
+        self.one_color_max_editor.setText("99.9")
+        self.one_color_max_editor.editingFinished.connect(self.onSingleColorChange)
 
         channel_label = QLabel("Channel", self)
+        channel_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignBottom)
         min_label = QLabel("Min", self)
+        min_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignBottom)
         max_label = QLabel("Max", self)
+        max_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignBottom)
 
         self.one_color_tab.setLayout(self.one_color_tab.layout)
         self.one_color_tab.layout.addWidget(QLabel(), 0, 0)
@@ -207,102 +212,97 @@ class ControlWidget(QtWidgets.QWidget):
 
 
     def initThreeColorUI(self):
-        self.three_color_tab.layout = QtWidgets.QVBoxLayout(self)
-        header_layout = QtWidgets.QHBoxLayout()
-        header_layout.addWidget(QLabel())
+        self.three_color_tab.layout = QtWidgets.QGridLayout(self)
+
         channel_label = QLabel("Channel")
         channel_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignBottom)
-        header_layout.addWidget(channel_label)
         min_label = QLabel("Min")
         min_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignBottom)
-        header_layout.addWidget(min_label)
         max_label = QLabel("Max")
         max_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignBottom)
-        header_layout.addWidget(max_label)
         scale_label = QLabel("Scale")
         scale_label.setAlignment(QtCore.Qt.AlignHCenter | QtCore.Qt.AlignBottom)
-        header_layout.addWidget(scale_label)
 
-        self.red_layout = QtWidgets.QHBoxLayout()
         self.red_label = QLabel()
         self.red_label.setText("Red Channel")
         self.red_label.setAlignment(QtCore.Qt.AlignRight)
         self.red_combo_box = QComboBox()
         self.red_combo_box.addItems(self.annotator.composites.channels())
+        self.red_combo_box.setCurrentIndex(2)
         self.red_combo_box.currentTextChanged.connect(self.onThreeColorChange)
         self.red_min_editor = QLineEdit()
         self.red_min_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
         self.red_min_editor.setText("0.0")
-        self.red_min_editor.textEdited.connect(self.onThreeColorChange)
+        self.red_min_editor.editingFinished.connect(self.onThreeColorChange)
         self.red_max_editor = QLineEdit()
         self.red_max_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
-        self.red_max_editor.setText("100.0")
-        self.red_max_editor.textEdited.connect(self.onThreeColorChange)
+        self.red_max_editor.setText("100")
+        self.red_max_editor.editingFinished.connect(self.onThreeColorChange)
         self.red_scale_editor = QLineEdit()
-        self.red_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
-        self.red_scale_editor.setText("1.0")
-        self.red_scale_editor.textEdited.connect(self.onThreeColorChange)
-        self.red_layout.addWidget(self.red_label)
-        self.red_layout.addWidget(self.red_combo_box)
-        self.red_layout.addWidget(self.red_min_editor)
-        self.red_layout.addWidget(self.red_max_editor)
-        self.red_layout.addWidget(self.red_scale_editor)
+        self.red_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 2))
+        self.red_scale_editor.setText("0.25")
+        self.red_scale_editor.editingFinished.connect(self.onThreeColorChange)
 
-        self.green_layout = QtWidgets.QHBoxLayout()
         self.green_label = QLabel()
         self.green_label.setText("Green Channel")
         self.green_label.setAlignment(QtCore.Qt.AlignRight)
         self.green_combo_box = QComboBox()
         self.green_combo_box.addItems(self.annotator.composites.channels())
+        self.green_combo_box.setCurrentIndex(3)
         self.green_combo_box.currentTextChanged.connect(self.onThreeColorChange)
         self.green_min_editor = QLineEdit()
         self.green_min_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
         self.green_min_editor.setText("0.0")
-        self.green_min_editor.textEdited.connect(self.onThreeColorChange)
+        self.green_min_editor.editingFinished.connect(self.onThreeColorChange)
         self.green_max_editor = QLineEdit()
         self.green_max_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
-        self.green_max_editor.setText("100.0")
-        self.green_max_editor.textEdited.connect(self.onThreeColorChange)
+        self.green_max_editor.setText("100")
+        self.green_max_editor.editingFinished.connect(self.onThreeColorChange)
         self.green_scale_editor = QLineEdit()
-        self.green_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
-        self.green_scale_editor.setText("1.0")
-        self.green_scale_editor.textEdited.connect(self.onThreeColorChange)
-        self.green_layout.addWidget(self.green_label)
-        self.green_layout.addWidget(self.green_combo_box)
-        self.green_layout.addWidget(self.green_min_editor)
-        self.green_layout.addWidget(self.green_max_editor)
-        self.green_layout.addWidget(self.green_scale_editor)
+        self.green_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 2))
+        self.green_scale_editor.setText("0.25")
+        self.green_scale_editor.editingFinished.connect(self.onThreeColorChange)
 
-        self.blue_layout = QtWidgets.QHBoxLayout()
         self.blue_label = QLabel()
         self.blue_label.setText("Blue Channel")
         self.blue_label.setAlignment(QtCore.Qt.AlignRight)
         self.blue_combo_box = QComboBox()
         self.blue_combo_box.addItems(self.annotator.composites.channels())
+        self.blue_combo_box.setCurrentIndex(4)
         self.blue_combo_box.currentTextChanged.connect(self.onThreeColorChange)
         self.blue_min_editor = QLineEdit()
         self.blue_min_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
         self.blue_min_editor.setText("0.0")
-        self.blue_min_editor.textEdited.connect(self.onThreeColorChange)
+        self.blue_min_editor.editingFinished.connect(self.onThreeColorChange)
         self.blue_max_editor = QLineEdit()
         self.blue_max_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
-        self.blue_max_editor.setText("100.0")
-        self.blue_max_editor.textEdited.connect(self.onThreeColorChange)
+        self.blue_max_editor.setText("100")
+        self.blue_max_editor.editingFinished.connect(self.onThreeColorChange)
         self.blue_scale_editor = QLineEdit()
-        self.blue_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 1))
-        self.blue_scale_editor.setText("1.0")
-        self.blue_scale_editor.textEdited.connect(self.onThreeColorChange)
-        self.blue_layout.addWidget(self.blue_label)
-        self.blue_layout.addWidget(self.blue_combo_box)
-        self.blue_layout.addWidget(self.blue_min_editor)
-        self.blue_layout.addWidget(self.blue_max_editor)
-        self.blue_layout.addWidget(self.blue_scale_editor)
+        self.blue_scale_editor.setValidator(QDoubleValidator(0.0, 100.0, 2))
+        self.blue_scale_editor.setText("0.25")
+        self.blue_scale_editor.editingFinished.connect(self.onThreeColorChange)
 
         self.three_color_tab.setLayout(self.three_color_tab.layout)
-        self.three_color_tab.layout.addLayout(header_layout)
-        self.three_color_tab.layout.addLayout(self.red_layout)
-        self.three_color_tab.layout.addLayout(self.green_layout)
-        self.three_color_tab.layout.addLayout(self.blue_layout)
+        self.three_color_tab.layout.addWidget(self.red_label, 1, 0)
+        self.three_color_tab.layout.addWidget(self.green_label, 2, 0)
+        self.three_color_tab.layout.addWidget(self.blue_label, 3, 0)
+        self.three_color_tab.layout.addWidget(channel_label, 0, 1)
+        self.three_color_tab.layout.addWidget(self.red_combo_box, 1, 1)
+        self.three_color_tab.layout.addWidget(self.green_combo_box, 2, 1)
+        self.three_color_tab.layout.addWidget(self.blue_combo_box, 3, 1)
+        self.three_color_tab.layout.addWidget(min_label, 0, 2)
+        self.three_color_tab.layout.addWidget(self.red_min_editor, 1, 2)
+        self.three_color_tab.layout.addWidget(self.green_min_editor, 2, 2)
+        self.three_color_tab.layout.addWidget(self.blue_min_editor, 3, 2)
+        self.three_color_tab.layout.addWidget(max_label, 0, 3)
+        self.three_color_tab.layout.addWidget(self.red_max_editor, 1, 3)
+        self.three_color_tab.layout.addWidget(self.green_max_editor, 2, 3)
+        self.three_color_tab.layout.addWidget(self.blue_max_editor, 3, 3)
+        self.three_color_tab.layout.addWidget(scale_label, 0, 4)
+        self.three_color_tab.layout.addWidget(self.red_scale_editor, 1, 4)
+        self.three_color_tab.layout.addWidget(self.green_scale_editor, 2, 4)
+        self.three_color_tab.layout.addWidget(self.blue_scale_editor, 3, 4)
 
     def onTabChange(self):
         if self.tabs.currentIndex() == 0:
